@@ -406,6 +406,22 @@ final class CodeCoverage
         return (new TargetCollectionValidator)->validate($this->targetMapper(), $targets);
     }
 
+    /**
+     * @internal
+     */
+    public function driverIsPcov(): bool
+    {
+        return $this->driver->isPcov();
+    }
+
+    /**
+     * @internal
+     */
+    public function driverIsXdebug(): bool
+    {
+        return $this->driver->isXdebug();
+    }
+
     /**
      * @param false|TargetedLines $linesToBeCovered
      * @param TargetedLines       $linesToBeUsed
