@@ -15,15 +15,14 @@ use function str_ends_with;
 use function str_replace;
 use function substr;
 use Countable;
+use SebastianBergmann\CodeCoverage\Data\ProcessedClassType;
+use SebastianBergmann\CodeCoverage\Data\ProcessedFunctionType;
+use SebastianBergmann\CodeCoverage\Data\ProcessedTraitType;
 use SebastianBergmann\CodeCoverage\StaticAnalysis\LinesOfCode;
 use SebastianBergmann\CodeCoverage\Util\Percentage;
 
 /**
  * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
- *
- * @phpstan-import-type ProcessedFunctionType from File
- * @phpstan-import-type ProcessedClassType from File
- * @phpstan-import-type ProcessedTraitType from File
  */
 abstract class AbstractNode implements Countable
 {
@@ -186,11 +185,11 @@ abstract class AbstractNode implements Countable
         $ccn = 0;
 
         foreach ($this->classesAndTraits() as $classLike) {
-            $ccn += $classLike['ccn'];
+            $ccn += $classLike->ccn;
         }
 
         foreach ($this->functions() as $function) {
-            $ccn += $function['ccn'];
+            $ccn += $function->ccn;
         }
 
         return $ccn;
