@@ -1009,7 +1009,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -1090,7 +1091,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -1173,7 +1175,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -1252,7 +1255,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -1324,7 +1328,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -1373,7 +1378,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn($data[2], $data[3]);
 
         $filter = new Filter;
@@ -1482,7 +1488,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -1533,7 +1540,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn($data[2], $data[3]);
 
         $filter = new Filter;
@@ -1799,7 +1807,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     {
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(RawCodeCoverageData::fromXdebugWithoutPathCoverage(
                 [
                     TEST_FILES_PATH . 'source_with_ignore.php' => [
@@ -1833,7 +1842,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     {
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(RawCodeCoverageData::fromXdebugWithoutPathCoverage(
                 [
                     TEST_FILES_PATH . 'source_with_eval.php' => [
@@ -1869,7 +1879,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     {
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(RawCodeCoverageData::fromXdebugWithoutPathCoverage(
                 [
                     TEST_FILES_PATH . 'source_with_class_and_anonymous_function.php' => [
@@ -1909,7 +1920,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     {
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(RawCodeCoverageData::fromXdebugWithoutPathCoverage(
                 [
                     TEST_FILES_PATH . 'source_with_class_and_outside_function.php' => [
@@ -1944,7 +1956,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
@@ -2019,7 +2032,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('stop')
+        $stub
+            ->method('stop')
             ->willReturn(...$data);
 
         $filter = new Filter;
