@@ -75,29 +75,27 @@ final class ProcessedCodeCoverageDataTest extends TestCase
         $coverage->setFunctionCoverage(
             [
                 '/some/path/SomeClass.php' => [
-                    'SomeClass->firstFunction' => [
-                        'branches' => [
-                            0 => [
-                                'op_start'   => 0,
-                                'op_end'     => 14,
-                                'line_start' => 20,
-                                'line_end'   => 25,
-                                'hit'        => [],
-                                'out'        => [
-                                ],
-                                'out_hit' => [
-                                ],
-                            ],
+                    'SomeClass->firstFunction' => new ProcessedFunctionCoverageData(
+                        [
+                            0 => new ProcessedBranchCoverageData(
+                                0,
+                                14,
+                                20,
+                                25,
+                                [],
+                                [],
+                                [],
+                            ),
                         ],
-                        'paths' => [
-                            0 => [
-                                'path' => [
+                        [
+                            0 => new ProcessedPathCoverageData(
+                                [
                                     0 => 0,
                                 ],
-                                'hit' => [],
-                            ],
+                                [],
+                            ),
                         ],
-                    ],
+                    ),
                 ],
             ],
         );
@@ -106,75 +104,70 @@ final class ProcessedCodeCoverageDataTest extends TestCase
         $newCoverage->setFunctionCoverage(
             [
                 '/some/path/SomeClass.php' => [
-                    'SomeClass->firstFunction' => [
-                        'branches' => [
-                            0 => [
-                                'op_start'   => 0,
-                                'op_end'     => 14,
-                                'line_start' => 20,
-                                'line_end'   => 25,
-                                'hit'        => [],
-                                'out'        => [
-                                ],
-                                'out_hit' => [
-                                ],
-                            ],
-                            1 => [
-                                'op_start'   => 15,
-                                'op_end'     => 16,
-                                'line_start' => 26,
-                                'line_end'   => 27,
-                                'hit'        => [],
-                                'out'        => [
-                                ],
-                                'out_hit' => [
-                                ],
-                            ],
+                    'SomeClass->firstFunction' => new ProcessedFunctionCoverageData(
+                        [
+                            0 => new ProcessedBranchCoverageData(
+                                0,
+                                14,
+                                20,
+                                25,
+                                [],
+                                [],
+                                [],
+                            ),
+                            1 => new ProcessedBranchCoverageData(
+                                15,
+                                16,
+                                26,
+                                27,
+                                [],
+                                [],
+                                [],
+                            ),
                         ],
-                        'paths' => [
-                            0 => [
-                                'path' => [
+                        [
+                            0 => new ProcessedPathCoverageData(
+                                [
                                     0 => 0,
                                 ],
-                                'hit' => [],
-                            ],
-                            1 => [
-                                'path' => [
+                                [],
+                            ),
+                            1 => new ProcessedPathCoverageData(
+                                [
                                     0 => 1,
                                 ],
-                                'hit' => [],
-                            ],
+                                [],
+                            ),
                         ],
-                    ],
-                    'SomeClass->secondFunction' => [
-                        'branches' => [
-                            0 => [
-                                'op_start'   => 0,
-                                'op_end'     => 24,
-                                'line_start' => 30,
-                                'line_end'   => 35,
-                                'hit'        => [],
-                                'out'        => [
-                                ],
-                                'out_hit' => [
-                                ],
-                            ],
+                    ),
+                    'SomeClass->secondFunction' => new ProcessedFunctionCoverageData(
+                        [
+                            0 => new ProcessedBranchCoverageData(
+                                0,
+                                24,
+                                30,
+                                35,
+                                [],
+                                [],
+                                [],
+                            ),
                         ],
-                        'paths' => [
-                            0 => [
-                                'path' => [
+                        [
+                            0 => new ProcessedPathCoverageData(
+                                [
                                     0 => 0,
                                 ],
-                                'hit' => [],
-                            ],
+                                [],
+                            ),
                         ],
-                    ],
+                    ),
                 ],
             ],
         );
 
         $coverage->merge($newCoverage);
 
+        $this->assertIsArray($newCoverage->functionCoverage()['/some/path/SomeClass.php']);
         $this->assertArrayHasKey('SomeClass->secondFunction', $newCoverage->functionCoverage()['/some/path/SomeClass.php']);
     }
 }
